==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/igr-radial-area-series.js <==
import { __extends } from "tslib";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { IgrAnchoredRadialSeries } from "./igr-anchored-radial-series";
import { RadialAreaSeries } from "./RadialAreaSeries";
import { ensureEnum } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent radial area series.
*/
var IgrRadialAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRadialAreaSeries, _super);
    function IgrRadialAreaSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrRadialAreaSeries.prototype.createImplementation = function () {
        return new RadialAreaSeries();
    };
    Object.defineProperty(IgrRadialAreaSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialAreaSeries.prototype, "isArea", {
        /**
         * Gets whether the current series shows an area shape.
        */
        get: function () {
            return this.i.d8;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialAreaSeries.prototype, "unknownValuePlotting", {
        /**
         * Determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        */
        get: function () {
            return this.i.ya;
        },
        set: function (v) {
            this.i.ya = ensureEnum(UnknownValuePlotting_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrRadialAreaSeries;
}(IgrAnchoredRadialSeries));
export { IgrRadialAreaSeries };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/igr-radial-area-series.js <==
import { __extends } from "tslib";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { IgrAnchoredRadialSeries } from "./igr-anchored-radial-series";
import { RadialAreaSeries } from "./RadialAreaSeries";
import { ensureEnum } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent radial area series.
*/
var IgrRadialAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRadialAreaSeries, _super);
    function IgrRadialAreaSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrRadialAreaSeries.prototype.createImplementation = function () {
        return new RadialAreaSeries();
    };
    Object.defineProperty(IgrRadialAreaSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialAreaSeries.prototype, "isArea", {
        /**
         * Gets whether the current series shows an area shape.
        */
        get: function () {
            return this.i.et;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialAreaSeries.prototype, "unknownValuePlotting", {
        /**
         * Determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        */
        get: function () {
            return this.i.adl;
        },
        set: function (v) {
            this.i.adl = ensureEnum(UnknownValuePlotting_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrRadialAreaSeries;
}(IgrAnchoredRadialSeries));
export { IgrRadialAreaSeries };
